@@ -9,8 +9,8 @@
 #' @param citekey Optional vector of bibliographic citation keys for samples/studies in the meta-analysis (if multiple citekeys pertain to a given effect size, combine them into a single string entry with comma delimiters (e.g., "citkey1,citekey2").
 #' When \code{TRUE}, program will use sample-size weights, error variances estimated from the mean effect size, maximum likelihood variances, and normal-distribution confidence and credibility intervals.
 #' @param construct_x,construct_y Vector of construct names for constructs designated as "X" and as "Y".
-#' @param group1,group2 Vector of groups' names associated with effect sizes that represent pairwise contrasts. 
-#' @param wt_type Type of weight to use in the meta-analysis: native options are "sample_size", and "inv_var" (inverse error variance).
+#' @param group1,group2 Vector of groups' names associated with effect sizes that represent pairwise contrasts.
+#' @param wt_type Type of weight to use in the meta-analysis: native options are "sample_size" and "inv_var" (inverse error variance).
 #' Supported options borrowed from metafor are "DL", "HE", "HS", "SJ", "ML", "REML", "EB", and "PM"
 #' (see metafor documentation for details about the metafor methods).
 #' @param moderators Matrix of moderator variables to be used in the meta-analysis (can be a vector in the case of one moderator).
@@ -18,6 +18,7 @@
 #' @param moderator_type Type of moderator analysis ("none", "simple", or "hierarchical").
 #' @param data Data frame containing columns whose names may be provided as arguments to vector arguments and/or moderators.
 #' @param control Output from the \code{control_psychmeta()} function or a list of arguments controlled by the \code{control_psychmeta()} function. Ellipsis arguments will be screened for internal inclusion in \code{control}.
+#' @param weights Optional vector of weights to be used. When \code{weights} is non-NULL, these weights override the argument supplied to \code{wt_type}.
 #' @param ... Further arguments to be passed to functions called within the meta-analysis.
 #'
 #' @return A nested tabular object of the class "ma_psychmeta".
@@ -36,11 +37,11 @@
 ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL, 
                        construct_x = NULL, construct_y = NULL,
                        group1 = NULL, group2 = NULL,
-                       wt_type = c("sample_size", "inv_var", 
+                       wt_type = c("sample_size", "inv_var",
                                    "DL", "HE", "HS", "SJ", "ML", "REML", "EB", "PM"),
                        moderators = NULL, cat_moderators = TRUE,
                        moderator_type = c("simple", "hierarchical", "none"),
-                       data = NULL, control = control_psychmeta(), ...){
+                       data = NULL, control = control_psychmeta(), weights = NULL, ...){
      
      .dplyr.show_progress <- options()$dplyr.show_progress
      .psychmeta.show_progress <- psychmeta.show_progress <- options()$psychmeta.show_progress
@@ -49,9 +50,7 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
      
      call <- match.call()
      warn_obj1 <- record_warnings()
-
-     wt_type <- match.arg(wt_type, choices = c("sample_size", "inv_var", 
-                                               "DL", "HE", "HS", "SJ", "ML", "REML", "EB", "PM"))
+     
      moderator_type <- match.arg(moderator_type, choices = c("simple", "hierarchical", "none"))
      
      control <- control_psychmeta(.psychmeta_ellipse_args = list(...),
@@ -70,7 +69,6 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
      }
 
      moderator_type <- scalar_arg_warning(arg = moderator_type, arg_name = "moderator_type")
-     wt_type <- scalar_arg_warning(arg = wt_type, arg_name = "wt_type")
      conf_method <- scalar_arg_warning(arg = conf_method, arg_name = "conf_method")
      cred_method <- scalar_arg_warning(arg = cred_method, arg_name = "cred_method")
      conf_level <- interval_warning(interval = conf_level, interval_name = "conf_level", default = .95)
@@ -106,8 +104,20 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
           
           if(deparse(substitute(moderators))[1] != "NULL")
                moderators <- match_variables(call = call_full[[match("moderators",  names(call_full))]], arg = moderators, arg_name = "moderators", data = as_tibble(data), as_array = TRUE)
+          
+          if(deparse(substitute(weights))[1] != "NULL")
+               weights <- match_variables(call = call_full[[match("weights",  names(call_full))]], arg = weights, arg_name = "weights", data = data)
      }
-
+     
+     weights <- unlist(weights)
+     if(!is.null(weights)){
+          wt_type <- "custom"
+     }else{
+          wt_type <- match.arg(wt_type, choices = c("sample_size", "inv_var",
+                                                    "DL", "HE", "HS", "SJ", "ML", "REML", "EB", "PM"))
+     }
+     wt_type <- scalar_arg_warning(arg = wt_type, arg_name = "wt_type")
+     
      if(!is.null(moderators)){
           if(is.null(dim(moderators))){
                moderators <- as.data.frame(moderators)
@@ -147,6 +157,11 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
                     var_unbiased = var_unbiased)
 
      es_data <- data.frame(es = es, n = n, var_e = var_e)
+     if(wt_type == "custom"){
+          if(length(weights) != nrow(es_data))
+               stop("If weights are supplied manually (via the 'weights' argument), there must be as many weights as there are effect sizes", call. = FALSE)
+          es_data$weights <- weights
+     }
      if(is.null(sample_id)) sample_id <- paste0("Sample #", 1:nrow(es_data))
      if(!is.null(citekey)) es_data <- cbind(citekey = citekey, es_data)
      es_data <- cbind(sample_id = sample_id, es_data)
@@ -188,22 +203,26 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
           }
      es_data <- as_tibble(es_data)[valid_es,]
      if(!is.null(moderators)) moderators <- as_tibble(moderators)[valid_es,]
-          
-     if(!is.null(construct_x)| !is.null(construct_y) |!is.null(group1) | !is.null(group2)){
-          if(!is.null(moderators))
-               es_data <- cbind(es_data, moderators)
-
-          out <- es_data %>% group_by(.data$group1, .data$group2, .data$construct_x, .data$construct_y) %>%
-               do(ma_wrapper(es_data = if(is.null(moderator_names$all)){.data}else{.data[,!(colnames(.data) %in% moderator_names$all)]}, 
-                             es_type = "generic", ma_type = "bb", ma_fun = .ma_generic,
-                             moderator_matrix = if(is.null(moderator_names$all)){NULL}else{as.data.frame(.data)[,moderator_names$all]}, 
-                             moderator_type = moderator_type, cat_moderators = cat_moderators,
-                             
-                             ma_arg_list = list(conf_level = conf_level, cred_level = cred_level,
-                                                conf_method = conf_method, cred_method = cred_method, var_unbiased = var_unbiased, wt_type = wt_type),
-                             presorted_data = additional_args$presorted_data, analysis_id_variables = additional_args$analysis_id_variables,
-                             moderator_levels = moderator_levels, moderator_names = moderator_names) )
-
+     
+     if(!is.null(moderators))
+          es_data <- cbind(es_data, moderators)
+     
+     use_grouped_df <- !is.null(construct_x)| !is.null(construct_y) |!is.null(group1) | !is.null(group2)
+     if(use_grouped_df)
+          es_data <- es_data %>% group_by(.data$group1, .data$group2, .data$construct_x, .data$construct_y)
+     
+     out <- es_data %>% 
+          do(ma_wrapper(es_data = if(is.null(moderator_names$all)){.data}else{.data[,!(colnames(.data) %in% moderator_names$all)]}, 
+                        es_type = "generic", ma_type = "bb", ma_fun = .ma_generic,
+                        moderator_matrix = if(is.null(moderator_names$all)){NULL}else{as.data.frame(.data)[,moderator_names$all]}, 
+                        moderator_type = moderator_type, cat_moderators = cat_moderators,
+                        
+                        ma_arg_list = list(conf_level = conf_level, cred_level = cred_level,
+                                           conf_method = conf_method, cred_method = cred_method, var_unbiased = var_unbiased, wt_type = wt_type),
+                        presorted_data = additional_args$presorted_data, analysis_id_variables = additional_args$analysis_id_variables,
+                        moderator_levels = moderator_levels, moderator_names = moderator_names) )
+     
+     if(use_grouped_df){
           out <- ungroup(out)
           analysis_combs <- apply(out[,c("group1", "group2", "construct_x", "construct_y")], 1, function(x){
                paste(x, collapse = " ")
@@ -214,17 +233,8 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
           if(is.null(group1)) out$group1 <- NULL
           if(is.null(construct_y)) out$construct_y <- NULL
           if(is.null(construct_x)) out$construct_x <- NULL
-         
-     }else{
-          out <- ma_wrapper(es_data = es_data, es_type = "generic", ma_type = "bb", ma_fun = .ma_generic,
-                            moderator_matrix = moderators, moderator_type = moderator_type, cat_moderators = cat_moderators,
-                            
-                            ma_arg_list = list(conf_level = conf_level, cred_level = cred_level,
-                                               conf_method = conf_method, cred_method = cred_method, var_unbiased = var_unbiased, wt_type = wt_type),
-                            presorted_data = additional_args$presorted_data, analysis_id_variables = additional_args$analysis_id_variables,
-                            moderator_levels = moderator_levels, moderator_names = moderator_names) 
      }
-
+     
      out <- bind_cols(analysis_id = 1:nrow(out), out)
      attributes(out) <- append(attributes(out), list(call_history = list(call), 
                                                      inputs = inputs, 
@@ -276,6 +286,7 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
      if(wt_source == "psychmeta"){
           if(wt_type == "sample_size") wt_vec <- n
           if(wt_type == "inv_var") wt_vec <- 1 / var_e_vec
+          if(wt_type == "custom") wt_vec <- data$weights
      }
      if(wt_source == "metafor"){
           wt_vec <- as.numeric(metafor::weights.rma.uni(metafor::rma(yi = es, vi = var_e_vec,
@@ -302,6 +313,7 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, citekey = NULL,
                                    residual = es - mean_es)
           if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj)
           if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj)
+          if(any(colnames(data) == "original_order")) escalc_obj <- cbind(original_order = data$original_order, escalc_obj)
           class(escalc_obj) <- c("escalc", "data.frame")
      }
 
